p_revision = 297;

% Parameters for all experiments ******************************************
p_maxWeight                     = 1; 
p_minWeight                     = 0;
p_weightInitRange               = 0.01;
p_inhibWeightRange              = 1;
p_transmissionNoise             = 0.15;  

p_nr_neurons                    = 1000;
p_nr_excitatory                 = 800;
p_nr_inhibitory                 = p_nr_neurons - p_nr_excitatory;

p_probConnect                   = 0.1;

p_stepsPerSecond                = 1/p_samplingTime;

% Kappa in Eq. 7
p_k                             = -5;

% factos in Eq. 4
p_traceIncrementWithPC          = 0.5;
p_traceDecrementWithNC          = -1;

p_decayLT                       = 540000;

% Gamma in Eq. 8
p_activationFactor              = 0.2;

p_sampleThresholdEstimationInSec            = 10;
p_monitoringSlindingWindowLengthInSeconds    = 1;

p_modTC                         = 0.0; % in range [0.1, 1]

if p_modTC >= 0.1
    disp(['Warning: experiment with modTC > 0. Running experiment of section 5.3']);
    load aux/integrationErrorCompensation;
    p_maxModulation = 0.3 * integrationErrorCompensation(round(p_samplingTime/0.002)) * p_samplingTime;
    p_baseMod = 0;
else
    p_maxModulation = 0.12;
    p_baseMod = 0;
end

% Set this variable to 0 for using the short-term weight as eligibility
% trace as specified in section 5.2
p_elig                          = 0;
if p_elig == 0
    disp(['Warning: expeirment with eligibile weights. Experiment of section 5.2']);
end

% Set these two variables to 1 for seeing how the plain Hebbian rule fails.
p_plainHebbian = 0;
%p_maxModulation = 1;
p_squareTraces = 0;
if p_squareTraces == 1
    disp(['Warning: experiment with square traces! Experiment of section 5.3']);
end

% Set this variable to 1 or 2 to cause modulation to increase activity in the
% network 
% EXPERIMENT OF SECTION 5.4
% VALUE 1: modulation increase activation
% VALUE 2: modulation increase gamma
p_modulationContributesToActivity = 0;
if p_modulationContributesToActivity > 0
    disp(['Warning: Experiment of section 5.4']);
end
% this is multiplied by s_totalModulation in neuralComputation.m
p_modulationContributesToActivityFactor = 5 * 1/p_maxModulation; 
s_activationFactor = p_activationFactor;


% Simulation variables ****************************************************

s_output                    = mysymrand(stream, p_nr_neurons, 1, p_transmissionNoise);
s_totSteps                  = p_simTime / p_samplingTime;

s_time                      = 0;
s_remainingStepsInEstimation= 0;

s_stepsToReward             = -1;
s_stepsToPunishment         = -1;

s_modulation                = 0;
s_totalModulation           = 0;


s_cputime                   = zeros(1,5);

%s_connectivity = sparse((round(rand(stream,p_nr_neurons)+p_probConnect-0.5))...
%    .* (ones(p_nr_neurons) - diag(ones(1,p_nr_neurons))));

% new initialisation: each neuron receives inputs from 80% excitatory
% neurons and 20% inhibitory neurons
% from rev 276

s_connectivity = sparse(p_nr_neurons,p_nr_neurons);

t_excInputs = p_probConnect * p_nr_excitatory;
t_inhInputs = p_probConnect * p_nr_inhibitory;
%t_fromExc = zeros(p_nr_excitatory * p_probConnect,1);
%t_fromInh = zeros(p_nr_inhibitory * p_probConnect,1);
t_axonCount = zeros(p_nr_neurons,1);

for i = 1:p_nr_neurons
    % disp(['Setting dendrides for neuron ' num2str(i)]);
    t_avgExcitatoryDendrides = p_nr_excitatory * p_probConnect;
    t_dendrides = myrandi(stream,1,1, t_avgExcitatoryDendrides * 1.00, t_avgExcitatoryDendrides * 1.00);
    t_fromExc = zeros(t_dendrides,1);
    
    for j = 1:t_dendrides
        t_fromExc(j) = myrandi(stream,1,1,1,p_nr_excitatory);
        while size(find(t_fromExc == t_fromExc(j)),1) > 1 || t_fromExc(j) == j...
                || t_axonCount(t_fromExc(j)) > ( p_nr_neurons * p_probConnect)
            t_fromExc(j) = myrandi(stream,1,1,1,p_nr_excitatory);
        end
    end
    t_axonCount(t_fromExc) = t_axonCount(t_fromExc) + 1;
    
    t_avgInhibitoryDendrides = p_nr_inhibitory * p_probConnect;
    t_dendrides = myrandi(stream,1,1,t_avgInhibitoryDendrides * 0.95, t_avgInhibitoryDendrides * 1.05);
    t_fromInh = zeros(t_dendrides,1);
    
    for j = 1:t_dendrides
        t_fromInh(j) = myrandi(stream,1,1,p_nr_excitatory+1,p_nr_neurons);
        while size(find(t_fromInh == t_fromInh(j)),1) > 1 || t_fromInh(j) == j...
                || t_axonCount(t_fromInh(j)) > ( p_nr_neurons * p_probConnect)
            t_fromInh(j) = myrandi(stream,1,1,p_nr_excitatory+1,p_nr_neurons);
        end
    end
    t_axonCount(t_fromInh) = t_axonCount(t_fromInh) + 1;
    s_connectivity(t_fromExc,i) = 1;
    s_connectivity(t_fromInh,i) = 1;
end

s_neuronTypes = [ones(1,p_nr_excitatory) -ones(1,p_nr_inhibitory)]; 
s_connectionType = s_connectivity .* repmat(s_neuronTypes, p_nr_neurons, 1)';

% Inhibitory connections are 5 times more effective than excitatory
% connections
s_connectionTypeStrength = sparse(p_nr_neurons, p_nr_neurons);
s_connectionTypeStrength = s_connectionTypeStrength + s_connectivity .* p_k .* (s_connectionType == -1);
s_connectionTypeStrength = s_connectionTypeStrength + s_connectivity .* +1 .* (s_connectionType == 1);

s_weightSum = sparse(p_nr_neurons,p_nr_neurons);

% Initialising excitatory weights
s_weightM       = rand(stream, p_nr_neurons, p_nr_neurons)...
    .* p_maxWeight .* p_weightInitRange .* s_connectivity;

% Initialisaing inhibitory weights
%s_weightM(p_nr_excitatory+1:p_nr_neurons,:)       = rand(stream, p_nr_inhibitory, p_nr_neurons)...
%    .* p_maxWeight .* p_inhibWeightRange .* s_connectivity(p_nr_excitatory+1:p_nr_neurons,:);

% From r280, instead of random values for inhibition, fixed values are
% used. That is because inhibitory weights are not plastic, so the use of
% uniform values may be better for network regularity than random values
s_weightM(p_nr_excitatory+1:p_nr_neurons,:) =... 
    p_maxWeight .* 0.5 .* s_connectivity(p_nr_excitatory+1:p_nr_neurons,:);


s_shortTermHebb         = sparse(p_nr_neurons,p_nr_neurons);
s_shortTermHebbSquare   = s_shortTermHebb;

s_monitoringCorrSlindingW = zeros(1, p_stepsPerSecond * p_monitoringSlindingWindowLengthInSeconds);

l_modulation            = zeros(1, s_totSteps);
l_rareEventsRate        = zeros(1, s_totSteps);
l_posThreshold          = zeros(1, s_totSteps);
l_negThreshold          = zeros(1, s_totSteps);
l_thresholds            = zeros(s_totSteps,2);
l_corrPerStep           = zeros(s_totSteps,2);

t_stepsPerSecond        = 1/p_samplingTime;
t_sizeOfSlindingW       = p_stepsPerSecond * p_monitoringSlindingWindowLengthInSeconds;
t_updateThreshold       = 0;
t_startAtStep           = 2;
t_suspendExecutionVar   = 0;

s_positiveCorrThresholdSample = zeros(1, 1/p_samplingTime * p_sampleThresholdEstimationInSec);
s_negativeCorrThresholdSample = zeros(1, 1/p_samplingTime * p_sampleThresholdEstimationInSec);

%s_positiveCorrThresholdSample = zeros(1, 1/p_samplingTime * p_monitoringSlindingWindowLengthInSeconds);
%s_negativeCorrThresholdSample = zeros(1, 1/p_samplingTime * p_monitoringSlindingWindowLengthInSeconds);


p_HCPercentPerStep = p_HCPerSecond * p_samplingTime;
p_positiveCorrThreshold         = 1;
p_negativeCorrThreshold         = -1;

s_neuronInput         = zeros(p_nr_neurons,1);
s_stimuliInput        = zeros(p_nr_neurons,1);








