if exist('executingSet','var') == 0
    clear;
    disp('Instrumental Conditioning');
    
    p_simTime               = 6000;
    p_samplingTime          = 0.10;    
end

p_traceTC                   = 1;

p_HCPerSecond               = 0.01;

p_minTimeToUS               = 0.7;
p_maxTimeToUS               = 1.3;

p_minTimeBetweenStimuli     = 10;
p_maxTimeBetweenStimuli     = 30;

p_stimuliStrength           = 20;

p_neuronsInSet              = 100;
p_trialForCS2               = 100;

p_sampleThresholdEstimationInSec            = 10;
p_monitoringSlindingWindowLengthInSeconds   = 1;

% how much modulation should the neurons send to the network?
p_neuronsToModFactor = 2;

addpath common; 
addpath exp4;

userChoicesE4;

init;

createSets;

s_weightM(s_neuronsUS,s_neuronsVTAP) = p_maxWeight .* s_connectivity(s_neuronsUS,s_neuronsVTAP);

%Resetting plasticity after changing connectivity
s_plasticityM           = s_connectivity;
s_plasticityM(p_nr_excitatory + 1:p_nr_neurons,:) = 0;
t_numberOfSynapses      = nnz(s_connectivity);
t_numberOfPlasticSynapses = nnz(s_plasticityM);
t_nrOfCorrelationsPerSecond = sum(nnz(s_plasticityM))*t_stepsPerSecond;

% Derived parameters, logs and control variables -------------------------%

s_minStepsToUS              = round(p_minTimeToUS / p_samplingTime);
s_maxStepsToUS              = round(p_maxTimeToUS / p_samplingTime);
s_minStepsBetweenStimuli    = round(p_minTimeBetweenStimuli / p_samplingTime);
s_maxStepsBetweenStimuli    = round(p_maxTimeBetweenStimuli / p_samplingTime);

l_CS1VATPsynapses         = zeros(1,s_totSteps);
l_CS2VATPsynapses         = zeros(1,s_totSteps);
l_CS1USsynapses           = zeros(1,s_totSteps);
l_CS2USsynapses           = zeros(1,s_totSteps);
l_CS1Allsynapses           = zeros(1,s_totSteps);

l_numberOfPosHighCorrPerStep = zeros(1,s_totSteps);
l_numberOfNegHighCorrPerStep = zeros(1,s_totSteps);

l_USVTAPsynapses          = zeros(1,s_totSteps);
l_AllVTAPsynapses         = zeros(1,s_totSteps);
l_CS1                     = zeros(1,s_totSteps);
l_CS2                     = zeros(1,s_totSteps);
l_US                      = zeros(1,s_totSteps);

s_trial                 = 1;
s_stepsToUS             = -1;
s_stepsToCS1            = round( 10/p_samplingTime );%initial CS1 after 10s
s_stepsToCS2            = -1;

t_showOnceMore          = 0;
t_expNr                 = 4;


% Launching --------------------------------------------------------------%
    t_f4 = figure('Position',[0 900 1200 900]);
    t_an = annotation('textbox',...
    [0.708333333333334 0.892333333333333 0.05375 0.0288888888888889],...
    'String',{'trial: '},...
   'FontSize',14,...
    'FitBoxToText','off',...
    'LineStyle','none');
    
    t_pauseButton = uicontrol(t_f4, 'Style', 'pushbutton',...
        'String', 'Pause',...
        'Position', [0 0 100 30],...
        'Callback', 'pause');
    
    t_suspendButton = uicontrol(t_f4, 'Style', 'pushbutton',...
        'String', 'Suspend',...
        'Position', [100 0 100 30],...
        'Callback', 'suspendExecution');
    t_resumedButton = uicontrol(t_f4, 'Style', 'pushbutton',...
        'String', 'Resume',...
        'Position', [200 0 100 30],...
        'Callback', 'resume');
        
    t_subplot1 = subplot(4,1,1,'Parent',t_f4);
    t_subplot2 = subplot(4,1,2,'Parent',t_f4);
    t_subplot3 = subplot(4,1,3,'Parent',t_f4);
    t_subplot4 = subplot(4,1,4,'Parent',t_f4);

    runE4;

% Plotting results -------------------------------------------------------%

if t_suspendExecutionVar == 0    
    filename = ['e4r'  num2str(p_revision)  'seed' num2str(p_seedNumber) '_' num2str(p_samplingTime*1000) 'ms'...
        'time' num2str(s_time) 'trace' num2str(p_traceTC) '.mat'];
    save(filename);

    %plotE4r;
    s_cputime
else
   % save matlabTemp;
end


